==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/data_factory/form_factory/rich_text_form.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import 'package:collection/collection.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class RichTextFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;
  final String? tip;

  const RichTextFormFactory({
    Key? key,
    required this.displayName,
    required this.name,
    required this.onChanged,
    this.state,
    this.tip,
    this.value,
  }) : super(key: key);
  @override
  State<RichTextFormFactory> createState() => _TextFormState();
}

class _TextFormState extends State<RichTextFormFactory> {
  Map<String, dynamic> _value = {};

  @override
  void initState() {
    super.initState();
    _value = DataClassUtils.dynamicToMapStringDynamic(widget.value);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant RichTextFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    final tempValue = DataClassUtils.dynamicToMapStringDynamic(widget.value);

    if (!const MapEquality().equals(_value, tempValue)) {
      _value = tempValue;
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      onPressed: () async {
        await fullPageDialog(
          context: context,
          builder: (BuildContext context) => Builder(
            builder: (context) {
              return Scaffold(
                appBar: const ThemedAppBar(
                  navigateBackButton: true,
                ),
                body: ThemedEditor(
                  document: RichTextDocumentModel.fromMap(
                    _value,
                  ),
                  editorContentCallback: ({
                    required RichTextDocumentModel document,
                  }) async {
                    final text = document.toMap();
                    setState(() {
                      _value = text;
                    });
                    widget.onChanged(widget.name, text);
                    widget.state?.didChange(text);
                    Navigator.pop(context);
                  },
                ),
              );
            },
          ),
        );
      },
      child: LayoutBuilder(builder: (context, constraints) {
        return SizedBox(
          width: constraints.maxWidth,
          height: constraints.maxHeight,
          child: SingleChildScrollView(
            child: ThemedEditor(
              document: RichTextDocumentModel.fromMap(
                _value,
              ),
              readonly: true,
            ),
          ),
        );
      }),
    );
  }
}

==> verttice_ui-0.1.10.tar.gz: lib/src/widgets/data_factory/form_factory/rich_text_form.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import 'package:collection/collection.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_types/verttice_types.dart';
// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class RichTextFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;
  final String? tip;

  const RichTextFormFactory({
    Key? key,
    required this.displayName,
    required this.name,
    required this.onChanged,
    this.state,
    this.tip,
    this.value,
  }) : super(key: key);
  @override
  State<RichTextFormFactory> createState() => _TextFormState();
}

class _TextFormState extends State<RichTextFormFactory> {
  Map<String, dynamic> _value = {};

  @override
  void initState() {
    super.initState();
    _value = DataClassUtils.dynamicToMapStringDynamic(widget.value);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant RichTextFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    final tempValue = DataClassUtils.dynamicToMapStringDynamic(widget.value);

    if (!const MapEquality().equals(_value, tempValue)) {
      _value = tempValue;
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      onPressed: () async {
        await fullPageDialog(
          context: context,
          builder: (BuildContext context) => Builder(
            builder: (context) {
              return Scaffold(
                appBar: const ThemedAppBar(
                  navigateBackButton: true,
                ),
                body: ThemedEditor(
                  document: RichTextDocumentModel.fromMap(
                    _value,
                  ),
                  editorContentCallback: ({
                    required RichTextDocumentModel document,
                  }) async {
                    final text = document.toMap();
                    setState(() {
                      _value = text;
                    });
                    widget.onChanged(widget.name, text);
                    widget.state?.didChange(text);
                    Navigator.pop(context);
                  },
                ),
              );
            },
          ),
        );
      },
      child: LayoutBuilder(builder: (context, constraints) {
        return SizedBox(
          width: constraints.maxWidth,
          height: constraints.maxHeight,
          child: SingleChildScrollView(
            child: ThemedEditor(
              document: RichTextDocumentModel.fromMap(
                _value,
              ),
              readonly: true,
            ),
          ),
        );
      }),
    );
  }
}
